Transports - kombu.transport — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# Transports - kombu.transport

`kombu.transport.` `get_transport_cls`(transport=None)

  Get transport class by name.

  The transport string is the full path to a transport class, e.g.:

      "kombu.transport.pyamqplib.Transport"

  If the name does not include “`.`” (is not fully qualified), the alias table will be consulted.

`kombu.transport.` `resolve_transport`(transport=None)

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »